@@ -71,6 +71,7 @@ static const R_CallMethodDef callMethods[] = {
     {"copyLp",                    (DL_FUNC) &copyLp,                   15},
     {"copyLpwNames",              (DL_FUNC) &copyLpwNames,             17},
     {"copyQuad",                  (DL_FUNC) &copyQuad,                  6},
+    {"copyQPsep",                 (DL_FUNC) &copyQPsep,                 3},
     {"writeProb",                 (DL_FUNC) &writeProb,                 4},
     {"readCopyProb",              (DL_FUNC) &readCopyProb,              4},
     {"dualWrite",                 (DL_FUNC) &dualWrite,                 3},
@@ -222,6 +223,7 @@ static const R_CallMethodDef callMethods[] = {
     {"checkCopyLp",               (DL_FUNC) &checkCopyLp,              15},
     {"checkCopyLpwNames",         (DL_FUNC) &checkCopyLpwNames,        17},
     {"checkCopyQuad",             (DL_FUNC) &checkCopyQuad,             6},
+    {"checkCopyQPsep",            (DL_FUNC) &checkCopyQPsep,            3},
     {"checkAddRows",              (DL_FUNC) &checkAddRows,             12},
     {"checkAddCols",              (DL_FUNC) &checkAddCols,             11},
     {"checkChgCoefList",          (DL_FUNC) &checkChgCoefList,          6},
